#IRS data scraped from https://www.irs.gov/forms-pubs/ebook
import os
import requests
from bs4 import BeautifulSoup
from urllib.parse import urljoin


def download_epub_files(url, download_dir):
    # Send a GET request to the URL
    response = requests.get(url)
    if response.status_code != 200:
        print(f"Failed to fetch the page. Error code: {response.status_code}")
        return

    # Parse the HTML content
    soup = BeautifulSoup(response.content, 'html.parser')

    # Find all the EPUB download links
    epub_links = soup.select('a[href$=".epub"]')

    # Create the download directory if it doesn't exist
    os.makedirs(download_dir, exist_ok=True)

    # Download each EPUB file
    for link in epub_links:
        file_url = urljoin(url, link['href'])
        filename = os.path.join(download_dir, link.text.strip() + '.epub')

        # Send a GET request to the EPUB file URL
        file_response = requests.get(file_url)
        if file_response.status_code == 200:
            # Save the EPUB file
            with open(filename, 'wb') as file:
                file.write(file_response.content)
                print(f"Downloaded: {filename}")
        else:
            print(f"Failed to download: {filename}")


# URL of the webpage containing EPUB files
url = 'https://www.irs.gov/forms-pubs/ebook'

# Directory to save the downloaded EPUB files
download_directory = 'E:\Dojo\Internship\week 4\streamlit_init\content\download'

# Download EPUB files from the URL
download_epub_files(url, download_directory)